@@ -37,17 +37,23 @@ pub trait AssocStatic<T> {
 #[macro_export]
 macro_rules! assoc_static {
     ($T:ty, $TARGET:ty, $INIT:expr) => {
-        impl AssocStatic<$TARGET> for $T {
+        impl $crate::AssocStatic<$TARGET> for $T {
             fn get_static() -> &'static $TARGET {
-                use std::marker::PhantomData;
-                static STATIC_ASSOCIATED: ($TARGET, PhantomData<$TARGET>, PhantomData<$T>) =
-                    ($INIT, PhantomData, PhantomData);
-                &STATIC_ASSOCIATED.0
+                static ASSOCIATED_STATIC: (
+                    $TARGET,
+                    std::marker::PhantomData<$crate::MakeSync<&$T>>,
+                ) = ($INIT, std::marker::PhantomData);
+                &ASSOCIATED_STATIC.0
             }
         }
     };
 }
 
+/// Only a helper, needs to be public because of the macro
+#[doc(hidden)]
+pub struct MakeSync<T>(T);
+unsafe impl<T> Sync for MakeSync<T> {}
+
 #[cfg(test)]
 mod tests {
     use crate::AssocStatic;
